TrojanURL class
- Inheritance
-
- Object
- FlutterVlessURL
- TrojanURL
Properties
- address → String
-
no setteroverride
- allowInsecure → bool
-
no setterinherited
- flow ↔ String
-
getter/setter pair
-
fullConfiguration
→ Map<
String, dynamic> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → int
-
no setterinherited
- network → String
-
no setterinherited
-
outbound1
→ Map<
String, dynamic> -
no setteroverride
- port → int
-
no setteroverride
- remark → String
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- security → String
-
no setterinherited
-
streamSetting
→ Map<
String, dynamic> -
no setterinherited
- streamSettingsBuilder → XrayStreamSettingsBuilder
-
latefinalinherited
- uri ↔ Uri
-
latefinal
- url → String
-
finalinherited
Methods
-
buildProxyOutbound(
{required String protocol, required Map< String, dynamic> settings}) → Map<String, dynamic> -
inherited
-
decodeXhttpExtra(
String? extra) → Map< String, dynamic> ? -
Decodes the XHTTP
extraJSON object from URL query parameters.inherited -
emptyToDefault(
String? value, String fallback) → String -
inherited
-
getFullConfiguration(
{int indent = 2}) → String -
Generate Full Configuration
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
populateTlsSettings(
{required String? streamSecurity, required bool allowInsecure, required String? sni, required String? fingerprint, required String? alpns, required String? publicKey, required String? shortId, required String? spiderX}) → void -
inherited
-
populateTransportSettings(
{required String transport, required String? headerType, required String? host, required String? path, required String? seed, required String? quicSecurity, required String? key, required String? mode, required String? serviceName, String? extra}) → String -
Populates Xray
streamSettingsfrom VLESS URL query parameters.inherited -
removeNulls(
dynamic params) → dynamic -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited