XrayConfigDocument class
- Implemented types
Constructors
-
XrayConfigDocument({required XrayLog log, required List<
XrayInbound> inbounds, required List<XrayOutbound> outbounds, required XrayRouting routing}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inbounds
→ List<
XrayInbound> -
final
- log → XrayLog
-
final
-
outbounds
→ List<
XrayOutbound> -
final
- routing → XrayRouting
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → JsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited