XrayRouting class

Implemented types

Constructors

XrayRouting({String domainStrategy = 'AsIs', String? domainMatcher, List<JsonMap> rules = const [], List<JsonMap> balancers = const []})
const

Properties

balancers → List<JsonMap>
final
domainMatcher → String?
final
domainStrategy → String
final
hashCode → int
The hash code for this object.
no setterinherited
rules → List<JsonMap>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → JsonMap
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited