XrayStreamSettings class

Implemented types

Constructors

XrayStreamSettings({required String network, required String security, JsonMap? tcpSettings, JsonMap? kcpSettings, JsonMap? wsSettings, JsonMap? httpSettings, JsonMap? h2Settings, JsonMap? tlsSettings, JsonMap? quicSettings, JsonMap? realitySettings, JsonMap? grpcSettings, JsonMap? xhttpSettings, JsonMap? dsSettings, JsonMap? sockopt})
const

Properties

dsSettings JsonMap?
final
grpcSettings JsonMap?
final
h2Settings JsonMap?
final
hashCode int
The hash code for this object.
no setterinherited
httpSettings JsonMap?
final
kcpSettings JsonMap?
final
network String
final
quicSettings JsonMap?
final
realitySettings JsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
security String
final
sockopt JsonMap?
final
tcpSettings JsonMap?
final
tlsSettings JsonMap?
final
wsSettings JsonMap?
final
xhttpSettings JsonMap?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() JsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited