XrayInbound class
- Implemented types
Constructors
- XrayInbound({required String tag, required int port, required String protocol, String? listen, JsonMap settings = const {}, XraySniffing? sniffing, JsonMap? streamSettings, JsonMap? allocate})
-
const
- XrayInbound.localSocksTunnel({String tag = 'in_proxy', String listen = '127.0.0.1', int port = 10807, int userLevel = 8})
-
factory
Properties
- allocate → JsonMap?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- listen → String?
-
final
- port → int
-
final
- protocol → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → JsonMap
-
final
- sniffing → XraySniffing?
-
final
- streamSettings → JsonMap?
-
final
- tag → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → JsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited