XrayOutbound class
- Implemented types
Constructors
- XrayOutbound({required String tag, required String protocol, JsonMap settings = const {}, XrayStreamSettings? streamSettings, JsonMap? proxySettings, String? sendThrough, JsonMap? mux})
-
const
- XrayOutbound.blackhole()
-
factory
- XrayOutbound.direct()
-
factory
- XrayOutbound.proxy({required String protocol, required JsonMap settings, required XrayStreamSettings streamSettings})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mux → JsonMap?
-
final
- protocol → String
-
final
- proxySettings → JsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendThrough → String?
-
final
- settings → JsonMap
-
final
- streamSettings → XrayStreamSettings?
-
final
- tag → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → JsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited