XraySniffing class
- Implemented types
Constructors
-
XraySniffing({required bool enabled, required List<
String> destOverride, required bool metadataOnly}) -
const
Properties
-
destOverride
→ List<
String> -
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadataOnly → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → JsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited